@@ -7,13 +7,12 @@ class Registro:
     Classe geral que modela os registros existentes
     nos arquivos do modelo DECOMP.
     """
+
     def __init__(self, tamanho: int):
         self.tamanho = tamanho
 
     @abstractmethod
-    def le_registro(self,
-                    linha: str,
-                    coluna_inicio: int) -> Any:
+    def le_registro(self, linha: str, coluna_inicio: int) -> Any:
         """
         Função genérica para leitura de um valor de registro
         em uma linha de um arquivo.
@@ -21,11 +20,9 @@ class Registro:
         pass
 
     @abstractmethod
-    def le_linha_tabela(self,
-                        linha: str,
-                        coluna_inicio: int,
-                        num_espacos: int,
-                        num_colunas: int) -> List[Any]:
+    def le_linha_tabela(
+        self, linha: str, coluna_inicio: int, num_espacos: int, num_colunas: int
+    ) -> List[Any]:
         """
         Função genérica para leitura de uma linha de uma
         tabela com vários registros iguais.
@@ -37,6 +34,7 @@ class RegistroAn(Registro):
     """
     Registro de strings existente nos arquivos do NEWAVE.
     """
+
     def __init__(self, tamanho: int):
         super().__init__(tamanho)
 
@@ -45,23 +43,22 @@ class RegistroAn(Registro):
         Lê o conteúdo de uma string existente numa linha de um arquivo
         do NEWAVE e retorna o valor sem espaços adicionais.
         """
-        return linha[coluna_inicio:coluna_inicio + self.tamanho].strip()
+        return linha[coluna_inicio : coluna_inicio + self.tamanho].strip()
 
-    def le_linha_tabela(self,
-                        linha: str,
-                        coluna_inicio: int,
-                        num_espacos: int,
-                        num_colunas: int) -> List[str]:
+    def le_linha_tabela(
+        self, linha: str, coluna_inicio: int, num_espacos: int, num_colunas: int
+    ) -> List[str]:
         """
         Lê o conteúdo de uma linha de tabela com strings.
         """
         lista_valores: List[str] = []
         # Gera a lista com as colunas de início de cada valor
-        colunas_inicio = [coluna_inicio + i * (self.tamanho + num_espacos)
-                          for i in range(num_colunas)]
+        colunas_inicio = [
+            coluna_inicio + i * (self.tamanho + num_espacos)
+            for i in range(num_colunas)
+        ]
         for col in colunas_inicio:
-            lista_valores.append(self.le_registro(linha,
-                                                  col))
+            lista_valores.append(self.le_registro(linha, col))
         return lista_valores
 
 
@@ -69,6 +66,7 @@ class RegistroIn(Registro):
     """
     Registro de números inteiros existente nos arquivos do NEWAVE.
     """
+
     def __init__(self, tamanho: int):
         super().__init__(tamanho)
 
@@ -77,20 +75,20 @@ class RegistroIn(Registro):
         Lê o conteúdo de um inteiro existente numa linha de um arquivo
         do NEWAVE e retorna o valor já convertido.
         """
-        return int(linha[coluna_inicio:coluna_inicio + self.tamanho].strip())
+        return int(linha[coluna_inicio : coluna_inicio + self.tamanho].strip())
 
-    def le_linha_tabela(self,
-                        linha: str,
-                        coluna_inicio: int,
-                        num_espacos: int,
-                        num_colunas: int) -> List[int]:
+    def le_linha_tabela(
+        self, linha: str, coluna_inicio: int, num_espacos: int, num_colunas: int
+    ) -> List[int]:
         """
         Lê o conteúdo de uma linha de tabela com inteiros.
         """
         lista_valores: List[int] = []
         # Gera a lista com as colunas de início de cada valor
-        colunas_inicio = [coluna_inicio + i * (self.tamanho + num_espacos)
-                          for i in range(num_colunas)]
+        colunas_inicio = [
+            coluna_inicio + i * (self.tamanho + num_espacos)
+            for i in range(num_colunas)
+        ]
         for col in colunas_inicio:
             valor = self.le_registro(linha, col)
             if valor is None:
@@ -103,6 +101,7 @@ class RegistroFn(Registro):
     """
     Registro de números reais existente nos arquivos do NEWAVE.
     """
+
     def __init__(self, tamanho: int):
         super().__init__(tamanho)
 
@@ -111,21 +110,20 @@ class RegistroFn(Registro):
         Lê o conteúdo de um número existente numa linha de um arquivo
         do NEWAVE e retorna o valor já convertido.
         """
-        return float(linha[coluna_inicio:coluna_inicio + self.tamanho])
+        return float(linha[coluna_inicio : coluna_inicio + self.tamanho])
 
-    def le_linha_tabela(self,
-                        linha: str,
-                        coluna_inicio: int,
-                        num_espacos: int,
-                        num_colunas: int) -> List[float]:
+    def le_linha_tabela(
+        self, linha: str, coluna_inicio: int, num_espacos: int, num_colunas: int
+    ) -> List[float]:
         """
         Lê o conteúdo de uma linha de tabela com valores reais.
         """
         lista_valores: List[float] = []
         # Gera a lista com as colunas de início de cada valor
-        colunas_inicio = [coluna_inicio + i * (self.tamanho + num_espacos)
-                          for i in range(num_colunas)]
+        colunas_inicio = [
+            coluna_inicio + i * (self.tamanho + num_espacos)
+            for i in range(num_colunas)
+        ]
         for col in colunas_inicio:
-            lista_valores.append(self.le_registro(linha,
-                                                  col))
+            lista_valores.append(self.le_registro(linha, col))
         return lista_valores
