@@ -3,6 +3,7 @@ from idecomp.config import MAX_REES, MAX_SUBSISTEMAS, SUBSISTEMAS
 from idecomp._utils.bloco import Bloco
 from idecomp._utils.registros import RegistroAn, RegistroFn, RegistroIn
 from idecomp._utils.leiturablocos import LeituraBlocos
+
 # Imports de módulos externos
 import numpy as np  # type: ignore
 import pandas as pd  # type: ignore
@@ -13,14 +14,13 @@ class BlocoCMOSumario(Bloco):
     """
     Bloco com as informações do CMO por estágio e por subsistema.
     """
+
     str_inicio = "CUSTO MARGINAL DE OPERACAO  ($/MWh)"
     str_fim = ""
 
     def __init__(self):
 
-        super().__init__(BlocoCMOSumario.str_inicio,
-                         "",
-                         True)
+        super().__init__(BlocoCMOSumario.str_inicio, "", True)
 
         self._dados: pd.DataFrame = pd.DataFrame()
 
@@ -32,7 +32,6 @@ class BlocoCMOSumario(Bloco):
 
     # Override
     def le(self, arq: IO):
-
         def converte_tabela_em_df() -> pd.DataFrame:
             df = pd.DataFrame(tabela)
             cols = [f"Estágio {s}" for s in range(1, n_semanas + 1)]
@@ -46,16 +45,17 @@ class BlocoCMOSumario(Bloco):
         arq.readline()
         # Descobre o número de semanas
         linha = arq.readline()
-        sems = [s for s in linha.split(" ") if (len(s) > 0
-                                                and ("Sem" in s or
-                                                     "Mes" in s))]
+        sems = [
+            s
+            for s in linha.split(" ")
+            if (len(s) > 0 and ("Sem" in s or "Mes" in s))
+        ]
         reg_pat = RegistroAn(6)
         reg_cmo = RegistroFn(10)
         n_semanas = len(sems)
         subsistemas: List[str] = []
         patamares: List[str] = []
-        tabela = np.zeros((4 * len(SUBSISTEMAS),
-                           n_semanas))
+        tabela = np.zeros((4 * len(SUBSISTEMAS), n_semanas))
         # Salta outra linha
         arq.readline()
         i = 0
@@ -73,10 +73,7 @@ class BlocoCMOSumario(Bloco):
             subsistemas.append(ssis)
             patamares.append(pat)
             # Semanas
-            tabela[i, :] = reg_cmo.le_linha_tabela(linha,
-                                                   11,
-                                                   1,
-                                                   n_semanas)
+            tabela[i, :] = reg_cmo.le_linha_tabela(linha, 11, 1, n_semanas)
             i += 1
 
     # Override
@@ -89,14 +86,15 @@ class BlocoGeracaoTermicaSubsistemaSumario(Bloco):
     Bloco com as informações de eco dos dados gerais
     utilizados na execução do caso.
     """
+
     str_inicio = "GERACAO TERMICA NOS SUSBSISTEMAS (MWmed)"
     str_fim = ""
 
     def __init__(self):
 
-        super().__init__(BlocoGeracaoTermicaSubsistemaSumario.str_inicio,
-                         "",
-                         True)
+        super().__init__(
+            BlocoGeracaoTermicaSubsistemaSumario.str_inicio, "", True
+        )
 
         self._dados: pd.DataFrame = pd.DataFrame()
 
@@ -108,7 +106,6 @@ class BlocoGeracaoTermicaSubsistemaSumario(Bloco):
 
     # Override
     def le(self, arq: IO):
-
         def converte_tabela_em_df() -> pd.DataFrame:
             df = pd.DataFrame(tabela)
             cols = [f"Estágio {s}" for s in range(1, n_semanas + 1)]
@@ -121,15 +118,16 @@ class BlocoGeracaoTermicaSubsistemaSumario(Bloco):
         arq.readline()
         # Descobre o número de semanas
         linha = arq.readline()
-        sems = [s for s in linha.split(" ") if (len(s) > 0
-                                                and ("Sem" in s or
-                                                     "Mes" in s))]
+        sems = [
+            s
+            for s in linha.split(" ")
+            if (len(s) > 0 and ("Sem" in s or "Mes" in s))
+        ]
         reg_ssis = RegistroAn(6)
         reg_gt = RegistroFn(10)
         n_semanas = len(sems)
         subsistemas: List[str] = []
-        tabela = np.zeros((MAX_SUBSISTEMAS,
-                           n_semanas))
+        tabela = np.zeros((MAX_SUBSISTEMAS, n_semanas))
         # Salta outra linha
         arq.readline()
         i = 0
@@ -145,10 +143,7 @@ class BlocoGeracaoTermicaSubsistemaSumario(Bloco):
             ssis = reg_ssis.le_registro(linha, 4)
             subsistemas.append(ssis)
             # Semanas
-            tabela[i, :] = reg_gt.le_linha_tabela(linha,
-                                                  11,
-                                                  1,
-                                                  n_semanas)
+            tabela[i, :] = reg_gt.le_linha_tabela(linha, 11, 1, n_semanas)
             i += 1
 
     # Override
@@ -161,14 +156,13 @@ class BlocoEnergiaArmazenadaREESumario(Bloco):
     Bloco com as informações de energia armazenada
     em percentual por REE.
     """
+
     str_inicio = "ENERGIA ARMAZENADA NOS REEs (%"
     str_fim = ""
 
     def __init__(self):
 
-        super().__init__(BlocoEnergiaArmazenadaREESumario.str_inicio,
-                         "",
-                         True)
+        super().__init__(BlocoEnergiaArmazenadaREESumario.str_inicio, "", True)
 
         self._dados: pd.DataFrame = pd.DataFrame()
 
@@ -180,11 +174,11 @@ class BlocoEnergiaArmazenadaREESumario(Bloco):
 
     # Override
     def le(self, arq: IO):
-
         def converte_tabela_em_df() -> pd.DataFrame:
             df = pd.DataFrame(tabela)
-            cols = ["Inicial"] + [f"Estágio {s}"
-                                  for s in range(1, n_semanas + 1)]
+            cols = ["Inicial"] + [
+                f"Estágio {s}" for s in range(1, n_semanas + 1)
+            ]
             df.columns = cols
             df["Subsistema"] = subsistemas
             df["REE"] = rees
@@ -195,16 +189,17 @@ class BlocoEnergiaArmazenadaREESumario(Bloco):
         arq.readline()
         # Descobre o número de semanas
         linha = arq.readline()
-        sems = [s for s in linha.split(" ") if (len(s) > 0
-                                                and ("Sem" in s or
-                                                     "Mes" in s))]
+        sems = [
+            s
+            for s in linha.split(" ")
+            if (len(s) > 0 and ("Sem" in s or "Mes" in s))
+        ]
         reg_ree = RegistroAn(12)
         reg_ssis = RegistroIn(4)
         n_semanas = len(sems)
         rees: List[str] = []
         subsistemas: List[int] = []
-        tabela = np.zeros((MAX_REES,
-                           n_semanas + 1))
+        tabela = np.zeros((MAX_REES, n_semanas + 1))
         # Salta outra linha
         arq.readline()
         i = 0
@@ -243,14 +238,15 @@ class BlocoEnergiaArmazenadaSubsistemaSumario(Bloco):
     Bloco com as informações de energia armazenada
     em percentual por REE.
     """
+
     str_inicio = "ENERGIA ARMAZENADA NOS SUBSISTEMAS (%"
     str_fim = ""
 
     def __init__(self):
 
-        super().__init__(BlocoEnergiaArmazenadaSubsistemaSumario.str_inicio,
-                         "",
-                         True)
+        super().__init__(
+            BlocoEnergiaArmazenadaSubsistemaSumario.str_inicio, "", True
+        )
 
         self._dados: pd.DataFrame = pd.DataFrame()
 
@@ -262,11 +258,11 @@ class BlocoEnergiaArmazenadaSubsistemaSumario(Bloco):
 
     # Override
     def le(self, arq: IO):
-
         def converte_tabela_em_df() -> pd.DataFrame:
             df = pd.DataFrame(tabela)
-            cols = ["Inicial"] + [f"Estágio {s}"
-                                  for s in range(1, n_semanas + 1)]
+            cols = ["Inicial"] + [
+                f"Estágio {s}" for s in range(1, n_semanas + 1)
+            ]
             df.columns = cols
             df["Subsistema"] = subsistemas
             df = df[["Subsistema"] + cols]
@@ -276,15 +272,16 @@ class BlocoEnergiaArmazenadaSubsistemaSumario(Bloco):
         arq.readline()
         # Descobre o número de semanas
         linha = arq.readline()
-        sems = [s for s in linha.split(" ") if (len(s) > 0
-                                                and ("Sem" in s or
-                                                     "Mes" in s))]
+        sems = [
+            s
+            for s in linha.split(" ")
+            if (len(s) > 0 and ("Sem" in s or "Mes" in s))
+        ]
         reg_ssis = RegistroAn(12)
         reg_earm = RegistroFn(6)
         n_semanas = len(sems)
         subsistemas: List[str] = []
-        tabela = np.zeros((MAX_SUBSISTEMAS,
-                           n_semanas + 1))
+        tabela = np.zeros((MAX_SUBSISTEMAS, n_semanas + 1))
         # Salta outra linha
         arq.readline()
         i = 0
@@ -300,10 +297,7 @@ class BlocoEnergiaArmazenadaSubsistemaSumario(Bloco):
             ssis = reg_ssis.le_registro(linha, 4)
             subsistemas.append(ssis)
             # Semanas
-            tabela[i, :] = reg_earm.le_linha_tabela(linha,
-                                                    23,
-                                                    1,
-                                                    n_semanas + 1)
+            tabela[i, :] = reg_earm.le_linha_tabela(linha, 23, 1, n_semanas + 1)
             i += 1
 
     # Override
@@ -325,8 +319,8 @@ class LeituraSumario(LeituraBlocos):
     tipos de dados, dentre outras tarefas necessárias para a leitura.
 
     """
-    def __init__(self,
-                 diretorio: str):
+
+    def __init__(self, diretorio: str):
         super().__init__(diretorio)
 
     # Override
@@ -334,7 +328,9 @@ class LeituraSumario(LeituraBlocos):
         """
         Cria a lista de blocos a serem lidos no arquivo sumario.rvx.
         """
-        return ([BlocoCMOSumario(),
-                 BlocoEnergiaArmazenadaREESumario(),
-                 BlocoEnergiaArmazenadaSubsistemaSumario(),
-                 BlocoGeracaoTermicaSubsistemaSumario()])
+        return [
+            BlocoCMOSumario(),
+            BlocoEnergiaArmazenadaREESumario(),
+            BlocoEnergiaArmazenadaSubsistemaSumario(),
+            BlocoGeracaoTermicaSubsistemaSumario(),
+        ]
